from setuptools import setup, find_packages, version
import setuptools

classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Natural Language :: English',
    'Intended Audience :: Developers',
]

setup(
    name='gabiscal',
    version='0.0.1',
    description ='Very basic calculator',
    long_description='',
    url='',
    author='Gabriel Renom',
    author_email='',
    license='MIT',
    classifiers=classifiers,
    keywords='calculator',
    packages=find_packages(),
    install_requieres=[''])